# Copyright 2010-2013 Canonical Ltd.
from optparse import make_option

from django.core.management.base import BaseCommand, CommandError
from django.db import transaction

from offspring.web.queuemanager.metrics import (
    get_build_result_metrics, calculate_start_and_end)


class Command(BaseCommand):
    help = "Outputs some basic metrics."

    option_list = BaseCommand.option_list + (
        make_option(
            "--end", dest="end",
            help="End date e.g. 2013-06-05"),
        make_option(
            "--start", dest="start",
            help="Start date e.g. 2013-06-20"),
        )

    def handle(self, *args, **options):
        if options.get("start") and options.get("end"):
            start, end = calculate_start_and_end(
                options.get("start"), options.get("end"))
            if not end > start:
                raise CommandError("start date must be before end date")
            metrics = get_build_result_metrics(start, end)
        elif (options.get("start") and not options.get("end")) or (
            options.get("end") and not options.get("start")):
            raise CommandError("--start and --end must be supplied")
        else:
            metrics = get_build_result_metrics()

        for item, value in metrics:
            self.stdout.write("%s = %s\n" % (item, value))
